@@ -3,6 +3,7 @@
 # Write data in tabular text format
 # Philip R Brenan at gmail dot com, Appa Apps Ltd, 2016
 #-------------------------------------------------------------------------------
+# podDocumentation
 
 package Data::Table::Text;
 require v5.16.0;
@@ -14,7 +15,7 @@ use File::Glob qw(:bsd_glob);
 use POSIX qw(strftime);                                                         # http://www.cplusplus.com/reference/ctime/strftime/
 use Data::Dump qw(dump);
 
-our $VERSION = '2017.516';
+our $VERSION = '2017.717';
 
 &saveToS3('DataTableText') if 0;                                                # Save code
 
@@ -662,7 +663,9 @@ sub extractDocumentation()
      }
     elsif ($level and $L =~ /\A\s*sub\s*(.+?)\s*#\s*(.+?)\s*\Z/)                # Documentation for a method = sub name comment
      {my ($n, $d) = ($1, $2);                                                   # Name from sub, description from comment
+say STDERR "AAAA =", dump($n, $d);
       next if $d =~ /\A#/;                                                      # Private method if ##
+say STDERR "BBBB ";
       my $signature = $n =~ s/\A\s*\w+//gsr =~                                  # Signature
                             s/\A\(//gsr     =~
                             s/\)\s*(:lvalue\s*)?\Z//gsr =~
@@ -703,8 +706,8 @@ sub extractDocumentation()
    {my $n = $methodParms{$s};
     push @d, "L<$n|/$s>\n"
    }
-  push @d, <<END;                                                               # Standard stuff
-=head1 Installation
+  push @d, <<END =~ s/`/=/gsr;                                                     # Standard stuff
+`head1 Installation
 
 This module is written in 100% Pure Perl and is thus easy to read, use, modify
 and install.
@@ -716,18 +719,20 @@ Standard Module::Build process for building and installing modules:
   ./Build test
   ./Build install
 
-=head1 Author
+`head1 Author
 
 philiprbrenan\@gmail.com
 
 http://www.appaapps.com
 
-=head1 Copyright
+`head1 Copyright
 
 Copyright (c) 2016-2017 Philip R Brenan.
 
 This module is free software. It may be used, redistributed and/or modified
 under the same terms as Perl itself.
+
+`cut
 END
 
   writeFile(my $d = "doc.data",     join "\n", @d);                             # Write documentation file
@@ -793,6 +798,10 @@ xxx);
 
 1;
 
+# podDocumentation
+
+=pod
+
 =encoding utf-8
 
 =head1 Name
@@ -897,6 +906,8 @@ This module is free software. It may be used, redistributed and/or
 modified under the same terms as Perl itself.
 
 =cut
+# podDocumentation
+## pod2html --infile=lib/Data/Table/Text.pm --outfile=zzz.html
 
 __DATA__
 use Test::More tests => 61;
